/***************************************************************************
 *   Copyright (C) 2006 by André Lindhjem <belgarat@sdf.lonestar.org>,     *
 *                         Kjetil Holien <kjetil.holien@gmail.com>,        *
 *                         Terje Risa <terje.risa@gmail.com> &             *
 *                         Øyvind Nerbråten <oyvind@nerbraten.com>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************
 *
 * \file aac.h
 * \author André Lindhjem, Kjetil Holien, Terje Risa & Øyvind Nerbråten
 * \date 15.02.2006
 *
 * Functinality for controlling aac placyback using faad and ao. With the aac_play
 * function we can specify a mp4/aac file and start and stop offsets. The audio_play
 * function starts decoding the aac file.
 * Almost all of this file are copyed / inspired by the (minimalistic) FAAD API
 * and the FAAD frontend code.
 * 
 * To build with AAC support, this is required:
 * - faad2-0 and faad2-dev installed.
 * - faad and mp4ff must be linked during build. "gcc (....) -lfaad -lmp4ff"
 */

#ifndef AAC_H_
#define AAC_H_


#include <stdbool.h>

#include "audio.h"		/** audio_data_t */



/* ************************************************	*
 * 			Global function declarations  		  	*
 * ************************************************	*/

/**
 * Play a file.
 * @param struct_audio_data_t _data - the struct_audio_data_t that is passed to almost all functions in the audio module.
 */
bool aac_play (struct_audio_data_t *data);


/**
 * Initiates AAC decoder.
 * @param struct_audio_data_t _data - the struct_audio_data_t that is passed to almost all functions in the audio module.
 */
void aac_initiate (struct_audio_data_t *data);


/**
 * Terminates AAC decoder.
 * @param struct_audio_data_t _data - the struct_audio_data_t that is passed to almost all functions in the audio module.
 */
void aac_terminate (struct_audio_data_t *data);


#endif /*AAC_H_*/
