/***************************************************************************
 *   Copyright (C) 2006 by André Lindhjem <belgarat@sdf.lonestar.org>,     *
 *                         Kjetil Holien <kjetil.holien@gmail.com>,        *
 *                         Terje Risa <terje.risa@gmail.com> &             *
 *                         Øyvind Nerbråten <oyvind@nerbraten.com>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************
 *
 * \file parsetime.c
 * \author André Lindhjem, Kjetil Holien, Terje Risa & Øyvind Nerbråten
 * \date 15.02.2006
 * 
 * This library parses valid DAISY time formats and constructs mad_timer_t
 */

#ifndef PARSETIME_H_
#define PARSETIME_H_



/* ************************************************	*
 * 	Global datastructures							*
 * ************************************************	*/

/**
 * Specifies type of time format.
 * Specifies whether a time format is Full-clock, Partial-clock or Timecount.
 */
enum pt_type {
	PT_INVALID_FORMAT	= -1,
	PT_FULL_CLOCK		= 0,
	PT_PARTIAL_CLOCK	= 1,
	PT_TIMECOUNT		= 2
};

/**
 * Specifies time units.
 */
enum pt_unit {
	PT_NO_UNIT 			= 0,
	PT_MILLISECONDS		= 1,
	PT_SECONDS 			= 2,
	PT_MINUTES 			= 3,
	PT_HOURS			= 4
};



/* ************************************************	*
 * 			Global function declarations  		  	*
 * ************************************************	*/

/**
 * Translates valid DAISY time formats to seconds and fractions
 * NOTE: sec. 7.7, (page 41) in ANSI/NISO Z39.86.2005
 * @param const char *expr - time as a null-terminated string.
 * @return mad_timer_t - returns the time as a mad_timer_t struct.
 */
mad_timer_t parse_time_mad_time_t (const char *expr);


/**
 * Translates valid DAISY time formats to milliseconds
 * Note: sec. 7.7, (page 41) in ANSI/NISO Z39.86.2005
 * @param const char *expr - time as a null-terminated string.
 * @return unsigned long int - time as milliseconds.
 */
unsigned long int parse_time_milliseconds (const char *expr);


/**
 * Returns the duration in milliseconds from char start- and stop-arguments
 * @param const char *start - start time as a null-terminated string.
 * @param const char *stop - stop time as a null-terminated string.
 * @return unsigned long int - duration (start to stop) as milliseconds.
 */
unsigned long int parse_time_get_dur (const char *start, const char *stop);


#endif /*PARSETIME_H_*/
